<?php 
define('PHPWG_ROOT_PATH','../../');

include_once( PHPWG_ROOT_PATH.'include/common.inc.php' );

if (!isset($rvm_dir))
  access_denied( 'Plugin not installed' );

include_once( dirname(__FILE__) .'/include/functions_map.php');
include_once( dirname(__FILE__) .'/include/functions.php');

rvm_load_language();
set_make_full_url();

$rewritten = '';
if ( $conf['question_mark_in_urls']==false and
     isset($_SERVER["PATH_INFO"]) and !empty($_SERVER["PATH_INFO"]) )
{
  $rewritten = $_SERVER["PATH_INFO"];
  $rewritten = str_replace('//', '/', $rewritten);
}
else
{
  foreach (array_keys($_GET) as $key)
  {
    $rewritten = $key;
    break;
  }
}
// deleting first "/" if displayed
$tokens = explode(
  '/',
  preg_replace('#^/#', '', $rewritten)
  );
$next_token = 0;
$result = rvm_parse_kml_url($tokens, $next_token);
$page = array_merge( $page, $result );

$forbidden = get_sql_condition_FandF(
      array
        (
          'forbidden_categories' => 'category_id',
          'visible_categories' => 'category_id',
          'visible_images' => 'i.id'
        ),
      'AND'
  );

$where_sql = 'i.lat IS NOT NULL ';
$where_sql .= $forbidden;

$img_fields = ' i.id,i.tn_ext,i.name,i.comment,i.file,i.path,i.lat,i.lon,i.date_creation';
 
build_section_items($img_fields, $where_sql, false);


$dataTpl = new Template( PHPWG_ROOT_PATH );
$dataTpl->set_filename('main', dirname(__FILE__).'/template/earth_kml.tpl' );

$dataTpl->assign_vars(
  array(
    'PAGE_TITLE' => strip_tags(@$page['title']),
    'CONTENT_ENCODING' => $lang_info['charset'],
    'PAGE_COMMENT' => strip_tags( @$page['comment'], '<a><br><p><b><i><small><strong><font>'),
    'U_INDEX' => duplicate_index_url( array('start'=>0) ),
  )
);

if ( !empty($page['items']) )
  $dataTpl->assign_var( 'NB_ITEMS_DESC', sprintf( l10n('%d images'), count($page['items']) ).'<br/>' );


// +-----------------------------------------------------------------------+
// |              sub categories network links                             |
// +-----------------------------------------------------------------------+
if ( 'categories'==$page['section'] and !isset($page['flat']) )
{
  $query = '
SELECT id, name, permalink, comment, uppercats, representative_picture_id
  FROM '.CATEGORIES_TABLE.' INNER JOIN '.USER_CACHE_CATEGORIES_TABLE.'
  ON id = cat_id and user_id = '.$user['id'].'
  WHERE id_uppercat '.
  (!isset($page['category']) ? 'is NULL' : '= '.$page['category']['id']).'
  ORDER BY rank
;';
//  echo "<pre>" . var_export($query,true);
  $result = pwg_query($query);
  $categories = array();
  $thumbnail_ids=array();
  while ($row = mysql_fetch_assoc($result))
  {
    array_push($categories, $row);
    if (isset($row['representative_picture_id']) and is_numeric($row['representative_picture_id']))
      array_push($thumbnail_ids, $row['representative_picture_id'] );
  }
  $thumbnail_src_of = array();
  if ( count($thumbnail_ids) )
  {
    $query = '
SELECT id, path, tn_ext
  FROM '.IMAGES_TABLE.'
  WHERE id IN ('.implode(',', $thumbnail_ids).')';
    $result = pwg_query($query);
    while ($row = mysql_fetch_assoc($result))
      $thumbnail_src_of[$row['id']] = get_thumbnail_url($row);
    unset($thumbnail_ids);
  }
  
  $cat_bounds = rvm_get_cat_bounds($forbidden);
  
  foreach ($categories as $category)
  {
    if ( !isset( $cat_bounds[ $category['id'] ] ) )
      continue; // without geo tagged images

    $bounds = $cat_bounds[ $category['id'] ];
    
    if ( isset($bounds['self']) )
    {
      $count_desc = l10n_dec('image_available', 'images_available', $bounds['self']['count']);
      if ( $bounds['self']['count'] == $bounds['count'] )
        $count_desc .= ' '.l10n('images_available_cpl');
      else
        $count_desc .= '/'.l10n_dec('image_available', 'images_available', $bounds['count']).' '.l10n_dec('images_available_cat','images_available_cats', $bounds['nb_cats'] );
    }
    else
      $count_desc = l10n_dec('image_available', 'images_available', $bounds['count'])
        .' '.l10n_dec('images_available_cat','images_available_cats', $bounds['nb_cats'] );
    
    $dataTpl->assign_block_vars( 'categories.category',
      array(
        'NAME'    => $category['name'],
        'COMMENT' => strip_tags(@$category['comment'], '<a><br><p><b><i><small><strong><font>'), 
        'U_CATEGORY' => make_index_url( array('category'=>$category) ),
        'U_KML'   => rvm_make_kml_index_url( array('section'=>'categories', 'category'=>$category) ),
        'U_MAP'   => rvm_make_map_index_url( array('section'=>'categories', 'category'=>$category) ),
        'COUNT_DESC' => $count_desc,
      )
      );
    if ( isset( $thumbnail_src_of[$category['representative_picture_id']] ) )
      $dataTpl->assign_block_vars( 'categories.category.representative', array( 'U_TN' => $thumbnail_src_of[$category['representative_picture_id']] ) );
      
    $dataTpl->assign_block_vars( 'categories.category.region', $bounds );
  }
}



// +-----------------------------------------------------------------------+
// | generate content for items                                            |
// +-----------------------------------------------------------------------+
$bounds = array();
foreach( $page['items'] as $img )
{
  $bounds = bounds_add($bounds, $img['lat'], $img['lon']);
  $params = array(
      'image_id' => $img['id'],
      'image_file' => $img['file'],
    );

  $page_url = duplicate_picture_url($params, array('start') );
  
  if (!empty( $img['name'] ) )
    $title = $img['name'];
  else
    $title = str_replace('_', ' ', get_filename_wo_extension($img['file']));

  $snippet = strip_tags(@$img['comment']);
  if (strlen($snippet)>80) $snippet = substr($snippet, 0, 80) . '...';
  $dataTpl->assign_block_vars( 'img', 
      array(
      'U_PAGE'=> $page_url,
      'U_TN'  => get_thumbnail_url($img),
      'TITLE'  => $title,
      'DESC'  => $img['comment'],
      'SNIPPET' => $snippet,
      'LAT'   => $img['lat'],
      'LON'   => $img['lon'],
      )
    );
  if ( isset($img['date_creation']) )
    $dataTpl->assign_block_vars( 'img.date_creation', array('date'=>$img['date_creation']) );
}

if ( !empty($bounds) )
  $dataTpl->assign_block_vars( 'region', $bounds );

/*header('Cache-Control: public' );
header('Expires: '.gmdate('D, d M Y H:i:s', time()+600).' GMT');
header('Pragma:');*/
header('Content-Disposition: inline; filename="'.str2url($page['title']).'";' );
header('Content-Type: application/vnd.google-earth.kml+xml; charset='.$lang_info['charset']);
if (isset($_GET['debug']))
  header('Content-Type: text/xml; charset='.$lang_info['charset']);


$dataTpl->pparse('main');

?>
