function PwgDataLoader( map )
{
  this._map = map;
  this._reloadDataTimeout = PwgDataLoader.defaultReloadDataTimeout;
}

PwgDataLoader.defaultReloadDataTimeout = 1800;

PwgDataLoader.prototype =  {

onDataLoading: null,
onDataLoadFailed: null,
onDataLoaded: null,

_urlMapData: null,
_timerReloadData: null,
_reloadDataTimeout: null,
_dataLoading: false,

_previousLoadDataReq : {box: null, zoom:0, resultBounds:null},

start: function(urlMapData)
{
  this._urlMapData = urlMapData;
  GEvent.bind( this._map, "movestart", this, this.clearTimerReloadData );
  GEvent.bind( this._map, "moveend", this, this._onMapMoveEnd );
  this._loadData();
},

clearTimerReloadData : function()
{
  if (this._timerReloadData)
  {
    clearTimeout( this._timerReloadData );
    this._timerReloadData = null;
    return true;
  }
  return false;
},

_onMapMoveEnd: function()
{
  this.clearTimerReloadData();
  this._timerReloadData = setTimeout(
    this._onTimeoutLoadData.bind(this),
    this._reloadDataTimeout);
},


_onTimeoutLoadData: function ()
{
  if (this._dataLoading) return; // still in progress
  this.clearTimerReloadData();
  this._loadData();
},

_loadData: function()
{
  var bounds = this._map.getBounds();

  var latRange = bounds.toSpan().lat();
  var latPrec = latRange * 32.0 / this._map.getSize().height;

  var lonRange = bounds.toSpan().lng();
  var lonPrec = ( lonRange>=0 ? lonRange : 360-lonRange )* 32.0 / this._map.getSize().width;

  if ( this._previousLoadDataReq.box!=null )
  { // not the first time
    if ( this._previousLoadDataReq.box.containsBounds( bounds ) )
    {
      if ( this._previousLoadDataReq.resultBounds == null )
        return; // no images here
      if ( this._map.getZoom() <= this._previousLoadDataReq.zoom )
        return;
      else
      {
        if (
          this._map.getZoom() == this._previousLoadDataReq.zoom + 1
          && this._map.getZoom() < this._map.getBoundsZoomLevel(this._previousLoadDataReq.resultBounds)
          )
        {
          if (document.is_debug) GLog.write('no load: zoom crt: '+this._map.getZoom()+'; prev: '+this._previousLoadDataReq.zoom+'; target: '+this._map.getBoundsZoomLevel(this._previousLoadDataReq.resultBounds));
          return;
        }
      }
    }
    else
    {
    }
  }

  var nd=0, sd=0, ed=0, wd=0;
  if ( !bounds.isFullLat() )
  {
    nd = latRange*12/100;
    sd = latRange*4/100;
  }
  if ( !bounds.isFullLng() )
  {
    ed = lonRange*9/100;
    wd = lonRange*7/100;
  }
  var box = new GLatLngBounds(
      new GLatLng( bounds.getSouthWest().lat()-sd, bounds.getSouthWest().lng()-wd ),
      new GLatLng( bounds.getNorthEast().lat()+nd, bounds.getNorthEast().lng()+ed )
    );
  
  var url = this._urlMapData;
  url += "&box=" + box.getSouthWest().toUrlValue(5) + "," + box.getNorthEast().toUrlValue(5);
  url += "&lap=" + latPrec.toString().substr(0,8);
  url += "&lop="+lonPrec.toString().substr(0,8);
  
  if (document.is_debug) {
    GLog.write( "bounds: " + bounds.getSouthWest().toUrlValue() + " " + bounds.getNorthEast().toUrlValue() +"; zoom: "+this._map.getZoom() +"; size: "+this._map.getSize().toString() +"; c: "+this._map.getCenter().toUrlValue() );
    GLog.writeUrl( url );
  }
  
  this._previousLoadDataReq.box = box;
  this._previousLoadDataReq.zoom = this._map.getZoom();
  this._previousLoadDataReq.resultBounds = null;
  this._dataLoading = true;

  if (this.onDataLoading) try { this.onDataLoading(); } catch(e){}
  try {
    GDownloadUrl(url, this._onDataReceived.bind(this) );
  }
  catch (e) {
    this._dataLoading = false;
    this._previousLoadDataReq.box=null;
    this._fireDataLoadFailed( 600, e );
  }
},

_onDataReceived: function(data, responseCode)
{
  var resp;
  this._dataLoading = false;
  if (responseCode!=200)
  {
    this._previousLoadDataReq.box=null;
    this._fireDataLoadFailed( responseCode, null );
    return;
  }

  try
  {
		eval('resp = ' + data);
		if (resp.nb_items == undefined)
      throw new Error( "DATA DECODING ERROR" );
      
		this._previousLoadDataReq.resultBounds = resp.bounds;
		if (document.is_debug && resp.debug) GLog.write( resp.debug );
		if (this.onDataLoaded!=null)
      this.onDataLoaded( resp );
	}
	catch (e)
	{
    this._previousLoadDataReq.box=null;
	  this._fireDataLoadFailed( responseCode, e );
		var s = e.message;
		s += '\n' + data.substr(0,1000);
		alert( s );
	}
},

_fireDataLoadFailed: function( responseCode, exception )
{
  try {
    if (this.onDataLoadFailed != null)
      this.onDataLoadFailed( responseCode, exception);
  }
  catch(e) {}
}

}

